@@ -50,6 +50,8 @@ class MoneyFieldProxy(object):
 
 class CurrencyField(models.CharField):
 
+    description = "A field which stores currency."
+
     def __init__(self, verbose_name=None, name=None, default=DEFAULT_CURRENCY, **kwargs):
         if isinstance(default, Currency):
             default = default.code
@@ -62,6 +64,8 @@ class CurrencyField(models.CharField):
 
 class MoneyField(models.DecimalField):
 
+    description = "A field which stores both the currency and amount of money."
+
     def __init__(self, verbose_name=None, name=None,
                  max_digits=None, decimal_places=None,
                  default=Decimal("0.0"), default_currency=DEFAULT_CURRENCY, **kwargs):
@@ -98,7 +102,7 @@ class MoneyField(models.DecimalField):
 
         from managers import money_manager
 
-        if hasattr(cls, '_default_manager'):
+        if getattr(cls, '_default_manager', None):
             cls._default_manager = money_manager(cls._default_manager)
         else:
             cls.objects = money_manager(models.Manager)
@@ -125,6 +129,10 @@ class MoneyField(models.DecimalField):
         defaults.update(kwargs)
         return super(MoneyField, self).formfield(**defaults)
 
+    def value_to_string(self, obj):
+        return obj.__dict__[self.attname].amount
+
+
 ## South support
 try:
     from south.modelsinspector import add_introspection_rules
